==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/GridColumnPinOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSimpleSectionBaseDescriptionMetadata } from "./GridColumnOptionsSimpleSectionBaseDescriptionMetadata";
import { GridColumnPinOptionsDescription } from "./GridColumnPinOptionsDescription";
/**
 * @hidden
 */
var GridColumnPinOptionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridColumnPinOptionsDescriptionMetadata, _super);
    function GridColumnPinOptionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnPinOptionsDescriptionMetadata.b = function (a) {
        if (GridColumnPinOptionsDescriptionMetadata.a == null) {
            GridColumnPinOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnPinOptionsDescriptionMetadata.c(GridColumnPinOptionsDescriptionMetadata.a);
        }
        if (a.k(GridColumnPinOptionsDescriptionMetadata.a)) {
            return;
        }
        a.aa(GridColumnPinOptionsDescriptionMetadata.a);
    };
    GridColumnPinOptionsDescriptionMetadata.c = function (a) {
        GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(a);
        a.item("PinLeftCaption", "String");
        a.item("PinRightCaption", "String");
    };
    GridColumnPinOptionsDescriptionMetadata.d = function (a) {
        GridColumnPinOptionsDescriptionMetadata.b(a);
        a.ac("GridColumnPinOptions", function () { return new GridColumnPinOptionsDescription(); });
        a.ab("GridColumnPinOptions", GridColumnPinOptionsDescriptionMetadata.a);
    };
    GridColumnPinOptionsDescriptionMetadata.$t = markType(GridColumnPinOptionsDescriptionMetadata, 'GridColumnPinOptionsDescriptionMetadata');
    GridColumnPinOptionsDescriptionMetadata.a = null;
    return GridColumnPinOptionsDescriptionMetadata;
}(Base));
export { GridColumnPinOptionsDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/GridColumnPinOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSimpleSectionBaseDescriptionMetadata } from "./GridColumnOptionsSimpleSectionBaseDescriptionMetadata";
import { GridColumnPinOptionsDescription } from "./GridColumnPinOptionsDescription";
/**
 * @hidden
 */
var GridColumnPinOptionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridColumnPinOptionsDescriptionMetadata, _super);
    function GridColumnPinOptionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnPinOptionsDescriptionMetadata.b = function (a) {
        if (GridColumnPinOptionsDescriptionMetadata.a == null) {
            GridColumnPinOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnPinOptionsDescriptionMetadata.c(GridColumnPinOptionsDescriptionMetadata.a);
        }
        if (a.k(GridColumnPinOptionsDescriptionMetadata.a)) {
            return;
        }
        a.ac(GridColumnPinOptionsDescriptionMetadata.a);
    };
    GridColumnPinOptionsDescriptionMetadata.c = function (a) {
        GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(a);
        a.item("PinLeftCaption", "String");
        a.item("PinRightCaption", "String");
    };
    GridColumnPinOptionsDescriptionMetadata.d = function (a) {
        GridColumnPinOptionsDescriptionMetadata.b(a);
        a.ae("GridColumnPinOptions", function () { return new GridColumnPinOptionsDescription(); });
        a.ad("GridColumnPinOptions", GridColumnPinOptionsDescriptionMetadata.a);
    };
    GridColumnPinOptionsDescriptionMetadata.$t = markType(GridColumnPinOptionsDescriptionMetadata, 'GridColumnPinOptionsDescriptionMetadata');
    GridColumnPinOptionsDescriptionMetadata.a = null;
    return GridColumnPinOptionsDescriptionMetadata;
}(Base));
export { GridColumnPinOptionsDescriptionMetadata };
